@@ -23,30 +23,12 @@ class CreateApiRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'CreateApi','apigateway')
 
-	def get_ResultDescriptions(self):
-		return self.get_query_params().get('ResultDescriptions')
-
-	def set_ResultDescriptions(self,ResultDescriptions):
-		self.add_query_param('ResultDescriptions',ResultDescriptions)
-
 	def get_WebSocketApiType(self):
 		return self.get_query_params().get('WebSocketApiType')
 
 	def set_WebSocketApiType(self,WebSocketApiType):
 		self.add_query_param('WebSocketApiType',WebSocketApiType)
 
-	def get_Visibility(self):
-		return self.get_query_params().get('Visibility')
-
-	def set_Visibility(self,Visibility):
-		self.add_query_param('Visibility',Visibility)
-
-	def get_GroupId(self):
-		return self.get_query_params().get('GroupId')
-
-	def set_GroupId(self,GroupId):
-		self.add_query_param('GroupId',GroupId)
-
 	def get_ErrorCodeSamples(self):
 		return self.get_query_params().get('ErrorCodeSamples')
 
@@ -59,11 +41,11 @@ class CreateApiRequest(RpcRequest):
 	def set_Description(self,Description):
 		self.add_query_param('Description',Description)
 
-	def get_ServiceConfig(self):
-		return self.get_query_params().get('ServiceConfig')
+	def get_DisableInternet(self):
+		return self.get_query_params().get('DisableInternet')
 
-	def set_ServiceConfig(self,ServiceConfig):
-		self.add_query_param('ServiceConfig',ServiceConfig)
+	def set_DisableInternet(self,DisableInternet):
+		self.add_query_param('DisableInternet',DisableInternet)
 
 	def get_ConstantParameters(self):
 		return self.get_query_params().get('ConstantParameters')
@@ -71,12 +53,6 @@ class CreateApiRequest(RpcRequest):
 	def set_ConstantParameters(self,ConstantParameters):
 		self.add_query_param('ConstantParameters',ConstantParameters)
 
-	def get_ResultType(self):
-		return self.get_query_params().get('ResultType')
-
-	def set_ResultType(self,ResultType):
-		self.add_query_param('ResultType',ResultType)
-
 	def get_AuthType(self):
 		return self.get_query_params().get('AuthType')
 
@@ -101,12 +77,6 @@ class CreateApiRequest(RpcRequest):
 	def set_FailResultSample(self,FailResultSample):
 		self.add_query_param('FailResultSample',FailResultSample)
 
-	def get_ApiName(self):
-		return self.get_query_params().get('ApiName')
-
-	def set_ApiName(self,ApiName):
-		self.add_query_param('ApiName',ApiName)
-
 	def get_SystemParameters(self):
 		return self.get_query_params().get('SystemParameters')
 
@@ -119,12 +89,6 @@ class CreateApiRequest(RpcRequest):
 	def set_ServiceParametersMap(self,ServiceParametersMap):
 		self.add_query_param('ServiceParametersMap',ServiceParametersMap)
 
-	def get_ResultSample(self):
-		return self.get_query_params().get('ResultSample')
-
-	def set_ResultSample(self,ResultSample):
-		self.add_query_param('ResultSample',ResultSample)
-
 	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
 
@@ -143,6 +107,54 @@ class CreateApiRequest(RpcRequest):
 	def set_RequestParameters(self,RequestParameters):
 		self.add_query_param('RequestParameters',RequestParameters)
 
+	def get_ResultDescriptions(self):
+		return self.get_query_params().get('ResultDescriptions')
+
+	def set_ResultDescriptions(self,ResultDescriptions):
+		self.add_query_param('ResultDescriptions',ResultDescriptions)
+
+	def get_Visibility(self):
+		return self.get_query_params().get('Visibility')
+
+	def set_Visibility(self,Visibility):
+		self.add_query_param('Visibility',Visibility)
+
+	def get_GroupId(self):
+		return self.get_query_params().get('GroupId')
+
+	def set_GroupId(self,GroupId):
+		self.add_query_param('GroupId',GroupId)
+
+	def get_ServiceConfig(self):
+		return self.get_query_params().get('ServiceConfig')
+
+	def set_ServiceConfig(self,ServiceConfig):
+		self.add_query_param('ServiceConfig',ServiceConfig)
+
+	def get_ResultType(self):
+		return self.get_query_params().get('ResultType')
+
+	def set_ResultType(self,ResultType):
+		self.add_query_param('ResultType',ResultType)
+
+	def get_ApiName(self):
+		return self.get_query_params().get('ApiName')
+
+	def set_ApiName(self,ApiName):
+		self.add_query_param('ApiName',ApiName)
+
+	def get_ResultSample(self):
+		return self.get_query_params().get('ResultSample')
+
+	def set_ResultSample(self,ResultSample):
+		self.add_query_param('ResultSample',ResultSample)
+
+	def get_ForceNonceCheck(self):
+		return self.get_query_params().get('ForceNonceCheck')
+
+	def set_ForceNonceCheck(self,ForceNonceCheck):
+		self.add_query_param('ForceNonceCheck',ForceNonceCheck)
+
 	def get_RequestConfig(self):
 		return self.get_query_params().get('RequestConfig')
 
